Muffin-REST
###########

.. _description:

Muffin-REST -- REST helpers for Muffin Framework.

.. _badges:

.. image:: http://img.shields.io/travis/klen/muffin-rest.svg?style=flat-square
    :target: http://travis-ci.org/klen/muffin-rest
    :alt: Build Status

.. image:: http://img.shields.io/pypi/v/muffin-rest.svg?style=flat-square
    :target: https://pypi.python.org/pypi/muffin-rest

.. image:: http://img.shields.io/pypi/dm/muffin-rest.svg?style=flat-square
    :target: https://pypi.python.org/pypi/muffin-rest

.. _contents:

.. contents::

.. _requirements:

Requirements
=============

- python >= 3.3

.. _installation:

Installation
=============

**Muffin-REST** should be installed using pip: ::

    pip install muffin-rest

.. _usage:

Usage
=====

.. _bugtracker:

Bug tracker
===========

If you have any suggestions, bug reports or
annoyances please report them to the issue tracker
at https://github.com/klen/muffin-rest/issues

.. _contributing:

Contributing
============

Development of Muffin-REST happens at: https://github.com/klen/muffin-rest


Contributors
=============

* klen_ (Kirill Klenov)

.. _license:

License
========

Licensed under a `MIT license`_.

If you wish to express your appreciation for the project, you are welcome to send
a postcard to: ::

    Kirill Klenov
    pos. Severny 8-3
    MO, Istra, 143500
    Russia

.. _links:

.. _klen: https://github.com/klen

.. _MIT license: http://opensource.org/licenses/MIT
